..
    This file is part of Invenio.
    Copyright (C) 2017-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

Use cases
=========

.. todo::

   Write this section

Integrated library system (ILS)
-------------------------------


Research data management (RDM)
------------------------------


Institutional repository (IR)
-----------------------------


Multimedia archive
------------------
